@@ -25,11 +25,16 @@ IntegerVariable <- R6Class(
     get_values = function(index = NULL) {
       if (is.null(index)) {
         return(integer_variable_get_values(self$.variable))
+      } else{
+        if (inherits(index, 'Bitset')){
+          return(integer_variable_get_values_at_index(self$.variable, index$.bitset))
+        } else {
+          stopifnot(all(index > 0))
+          stopifnot(all(is.finite(index)))
+          return(integer_variable_get_values_at_index_vector(self$.variable, index))
+        }
       }
-      if (is.numeric(index)) {
-        return(integer_variable_get_values_at_index_vector(self$.variable, index))
-      }
-      integer_variable_get_values_at_index(self$.variable, index$.bitset)
+      
     },
 
 
@@ -84,7 +89,7 @@ IntegerVariable <- R6Class(
       }
       stop("please provide a set of values to check, or both bounds of range [a,b]")    
     },
-
+    
     #' @description Queue an update for a variable. There are 4 types of variable update:
     #'
     #' \enumerate{
@@ -122,16 +127,25 @@ IntegerVariable <- R6Class(
         }
       } else {
         if (inherits(index, 'Bitset')) {
-          index <- index$to_vector()
-        }
-        if (length(index) != 0) {
-          stopifnot(all(index > 0))
-          integer_variable_queue_update(
-            self$.variable,
-            values,
-            index
-          )
+          if (index$size() > 0) {
+            integer_variable_queue_update_bitset(
+              self$.variable,
+              values,
+              index$.bitset
+            )
+          }
+        } else {
+          if (length(index) > 0) {
+            stopifnot(all(is.finite(index)))
+            stopifnot(all(index > 0))
+            integer_variable_queue_update(
+              self$.variable,
+              values,
+              index
+            )
+          }          
         }
+
       }
     },
 
